# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.9 Python SDK

    Pure Storage FlashBlade REST 1.9 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.9
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BucketS3PerformanceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'pagination_info': 'PaginationInfo',
        'total': 'list[BucketS3Performance]',
        'items': 'list[BucketS3Performance]'
    }

    attribute_map = {
        'pagination_info': 'pagination_info',
        'total': 'total',
        'items': 'items'
    }

    def __init__(self, pagination_info=None, total=None, items=None):  # noqa: E501
        """BucketS3PerformanceResponse - a model defined in Swagger"""  # noqa: E501

        self._pagination_info = None
        self._total = None
        self._items = None
        self.discriminator = None

        if pagination_info is not None:
            self.pagination_info = pagination_info
        if total is not None:
            self.total = total
        if items is not None:
            self.items = items

    @property
    def pagination_info(self):
        """Gets the pagination_info of this BucketS3PerformanceResponse.  # noqa: E501

        pagination information, only available in GET requests  # noqa: E501

        :return: The pagination_info of this BucketS3PerformanceResponse.  # noqa: E501
        :rtype: PaginationInfo
        """
        return self._pagination_info

    @pagination_info.setter
    def pagination_info(self, pagination_info):
        """Sets the pagination_info of this BucketS3PerformanceResponse.

        pagination information, only available in GET requests  # noqa: E501

        :param pagination_info: The pagination_info of this BucketS3PerformanceResponse.  # noqa: E501
        :type: PaginationInfo
        """

        self._pagination_info = pagination_info

    @property
    def total(self):
        """Gets the total of this BucketS3PerformanceResponse.  # noqa: E501

        Total of all records after filtering. If total_only query param is true, then no items will be returned.  # noqa: E501

        :return: The total of this BucketS3PerformanceResponse.  # noqa: E501
        :rtype: list[BucketS3Performance]
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this BucketS3PerformanceResponse.

        Total of all records after filtering. If total_only query param is true, then no items will be returned.  # noqa: E501

        :param total: The total of this BucketS3PerformanceResponse.  # noqa: E501
        :type: list[BucketS3Performance]
        """

        self._total = total

    @property
    def items(self):
        """Gets the items of this BucketS3PerformanceResponse.  # noqa: E501

        A list of S3 specific bucket performance metrics objects.  # noqa: E501

        :return: The items of this BucketS3PerformanceResponse.  # noqa: E501
        :rtype: list[BucketS3Performance]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this BucketS3PerformanceResponse.

        A list of S3 specific bucket performance metrics objects.  # noqa: E501

        :param items: The items of this BucketS3PerformanceResponse.  # noqa: E501
        :type: list[BucketS3Performance]
        """

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BucketS3PerformanceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BucketS3PerformanceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.11 Python SDK

    Pure Storage FlashBlade REST 1.11 Python SDK. Compatible with REST API versions 1.0 - 1.11. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.11
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .admin import Admin
from .admin_api_token import AdminApiToken
from .admin_cache import AdminCache
from .admin_cache_response import AdminCacheResponse
from .admin_response import AdminResponse
from .alert import Alert
from .alert_response import AlertResponse
from .alert_watcher import AlertWatcher
from .alert_watcher_post import AlertWatcherPost
from .alert_watcher_response import AlertWatcherResponse
from .alert_watcher_test import AlertWatcherTest
from .alert_watcher_test_response import AlertWatcherTestResponse
from .array_connection import ArrayConnection
from .array_connection_key import ArrayConnectionKey
from .array_connection_key_response import ArrayConnectionKeyResponse
from .array_connection_path import ArrayConnectionPath
from .array_connection_path_response import ArrayConnectionPathResponse
from .array_connection_post import ArrayConnectionPost
from .array_connection_response import ArrayConnectionResponse
from .array_http_performance import ArrayHttpPerformance
from .array_http_performance_response import ArrayHttpPerformanceResponse
from .array_nfs_performance import ArrayNfsPerformance
from .array_nfs_performance_response import ArrayNfsPerformanceResponse
from .array_performance import ArrayPerformance
from .array_performance_replication_response import ArrayPerformanceReplicationResponse
from .array_performance_response import ArrayPerformanceResponse
from .array_response import ArrayResponse
from .array_s3_performance import ArrayS3Performance
from .array_s3_performance_response import ArrayS3PerformanceResponse
from .array_space import ArraySpace
from .array_space_response import ArraySpaceResponse
from .audit import Audit
from .audit_response import AuditResponse
from .blade import Blade
from .blade_response import BladeResponse
from .bucket import Bucket
from .bucket_patch import BucketPatch
from .bucket_performance import BucketPerformance
from .bucket_performance_response import BucketPerformanceResponse
from .bucket_post import BucketPost
from .bucket_replica_link import BucketReplicaLink
from .bucket_replica_link_post import BucketReplicaLinkPost
from .bucket_replica_link_response import BucketReplicaLinkResponse
from .bucket_response import BucketResponse
from .bucket_s3_performance import BucketS3Performance
from .bucket_s3_performance_response import BucketS3PerformanceResponse
from ._built_in import BuiltIn
from ._built_in_with_id import BuiltInWithId
from .certificate import Certificate
from .certificate_group import CertificateGroup
from .certificate_group_response import CertificateGroupResponse
from .certificate_group_use import CertificateGroupUse
from .certificate_group_use_response import CertificateGroupUseResponse
from .certificate_post import CertificatePost
from .certificate_response import CertificateResponse
from .certificate_use import CertificateUse
from .certificate_use_response import CertificateUseResponse
from .client_performance import ClientPerformance
from .client_performance_response import ClientPerformanceResponse
from ._direction import Direction
from .directory_service import DirectoryService
from .directory_service_response import DirectoryServiceResponse
from .directory_service_role import DirectoryServiceRole
from .directory_service_roles_response import DirectoryServiceRolesResponse
from .directoryservice_management import DirectoryserviceManagement
from .directoryservice_nfs import DirectoryserviceNfs
from .directoryservice_smb import DirectoryserviceSmb
from .dns import Dns
from .dns_response import DnsResponse
from .error_response import ErrorResponse
from .file_system import FileSystem
from .file_system_patch import FileSystemPatch
from .file_system_performance import FileSystemPerformance
from .file_system_performance_response import FileSystemPerformanceResponse
from .file_system_replica_link import FileSystemReplicaLink
from .file_system_replica_link_response import FileSystemReplicaLinkResponse
from .file_system_response import FileSystemResponse
from .file_system_snapshot import FileSystemSnapshot
from .file_system_snapshot_response import FileSystemSnapshotResponse
from .file_system_snapshot_transfer_response import FileSystemSnapshotTransferResponse
from .file_system_snapshots_transfer import FileSystemSnapshotsTransfer
from ._fixed_reference import FixedReference
from ._fixed_reference_no_resource_type import FixedReferenceNoResourceType
from ._fixed_reference_with_id import FixedReferenceWithId
from ._fixed_reference_with_remote import FixedReferenceWithRemote
from .hardware import Hardware
from .hardware_connector import HardwareConnector
from .hardware_connector_response import HardwareConnectorResponse
from .hardware_response import HardwareResponse
from .keytab import Keytab
from .keytab_download_upload_response import KeytabDownloadUploadResponse
from .keytab_response import KeytabResponse
from .lifecycle_rule import LifecycleRule
from .lifecycle_rule_patch import LifecycleRulePatch
from .lifecycle_rule_post import LifecycleRulePost
from .lifecycle_rule_response import LifecycleRuleResponse
from .link_aggregation_group import LinkAggregationGroup
from .link_aggregation_group_patch import LinkAggregationGroupPatch
from .link_aggregation_group_response import LinkAggregationGroupResponse
from ._location_reference import LocationReference
from .log_download_response import LogDownloadResponse
from .login_banner_response import LoginBannerResponse
from .login_response import LoginResponse
from .member import Member
from ._member_link import MemberLink
from .member_response import MemberResponse
from .multi_protocol_rule import MultiProtocolRule
from .network_interface import NetworkInterface
from .network_interface_response import NetworkInterfaceResponse
from .nfs_rule import NfsRule
from .nfs_rule_patch import NfsRulePatch
from .object_response import ObjectResponse
from .object_store_access_key import ObjectStoreAccessKey
from .object_store_access_key_post import ObjectStoreAccessKeyPost
from .object_store_access_key_response import ObjectStoreAccessKeyResponse
from .object_store_account import ObjectStoreAccount
from .object_store_account_response import ObjectStoreAccountResponse
from .object_store_remote_credentials import ObjectStoreRemoteCredentials
from .object_store_remote_credentials_response import ObjectStoreRemoteCredentialsResponse
from .object_store_user import ObjectStoreUser
from .object_store_user_response import ObjectStoreUserResponse
from .pagination_info import PaginationInfo
from .performance_replication import PerformanceReplication
from .performance_replication_response import PerformanceReplicationResponse
from ._permission import Permission
from .policy import Policy
from .policy_member import PolicyMember
from .policy_member_response import PolicyMemberResponse
from .policy_member_with_remote import PolicyMemberWithRemote
from .policy_member_with_remote_response import PolicyMemberWithRemoteResponse
from .policy_patch import PolicyPatch
from ._policy_reference_with_id import PolicyReferenceWithId
from .policy_response import PolicyResponse
from ._policy_rule import PolicyRule
from .protocol_rule import ProtocolRule
from .pure_array import PureArray
from .pure_error import PureError
from .pure_object import PureObject
from .quotas_group import QuotasGroup
from .quotas_group_response import QuotasGroupResponse
from .quotas_setting import QuotasSetting
from .quotas_setting_response import QuotasSettingResponse
from .quotas_user import QuotasUser
from .quotas_user_response import QuotasUserResponse
from .quotasgroup_group import QuotasgroupGroup
from .quotasuser_user import QuotasuserUser
from .reference import Reference
from ._reference_name import ReferenceName
from .relationship_performance_replication import RelationshipPerformanceReplication
from .relationship_performance_replication_response import RelationshipPerformanceReplicationResponse
from ._replica_link_built_in import ReplicaLinkBuiltIn
from ._replication_performance import ReplicationPerformance
from ._resource import Resource
from ._resource_type import ResourceType
from .role import Role
from .role_response import RoleResponse
from .smb_rule import SmbRule
from .smtp import Smtp
from .smtp_response import SmtpResponse
from .snapshot_suffix import SnapshotSuffix
from .snmp_agent import SnmpAgent
from .snmp_agent_mib import SnmpAgentMib
from .snmp_agent_mib_response import SnmpAgentMibResponse
from .snmp_agent_response import SnmpAgentResponse
from .snmp_manager import SnmpManager
from .snmp_manager_post import SnmpManagerPost
from .snmp_manager_response import SnmpManagerResponse
from .snmp_manager_test import SnmpManagerTest
from .snmp_manager_test_response import SnmpManagerTestResponse
from ._snmp_v2c import SnmpV2c
from ._snmp_v3 import SnmpV3
from .space import Space
from .subnet import Subnet
from .subnet_response import SubnetResponse
from .support import Support
from .support_remote_assist_paths import SupportRemoteAssistPaths
from .support_response import SupportResponse
from .syslog_server import SyslogServer
from .syslog_server_post_or_patch import SyslogServerPostOrPatch
from .syslog_server_response import SyslogServerResponse
from .syslog_server_setting import SyslogServerSetting
from .syslog_server_setting_patch import SyslogServerSettingPatch
from .syslog_server_setting_response import SyslogServerSettingResponse
from .syslog_server_test import SyslogServerTest
from .syslog_server_test_response import SyslogServerTestResponse
from .target import Target
from .target_post import TargetPost
from .target_response import TargetResponse
from .test_result import TestResult
from .test_result_response import TestResultResponse
from .version_response import VersionResponse



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class BucketReplicaLink(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'direction': 'Direction',
        'id': 'str',
        'lag': 'int',
        'remote': 'FixedReferenceWithId',
        'status_details': 'str',
        'local_bucket': 'FixedReferenceWithId',
        'paused': 'bool',
        'recovery_point': 'int',
        'remote_bucket': 'Reference',
        'remote_credentials': 'Reference',
        'status': 'str'
    }

    attribute_map = {
        'direction': 'direction',
        'id': 'id',
        'lag': 'lag',
        'remote': 'remote',
        'status_details': 'status_details',
        'local_bucket': 'local_bucket',
        'paused': 'paused',
        'recovery_point': 'recovery_point',
        'remote_bucket': 'remote_bucket',
        'remote_credentials': 'remote_credentials',
        'status': 'status'
    }

    def __init__(self, direction=None, id=None, lag=None, remote=None, status_details=None, local_bucket=None, paused=None, recovery_point=None, remote_bucket=None, remote_credentials=None, status=None):  # noqa: E501
        """BucketReplicaLink - a model defined in Swagger"""  # noqa: E501

        self._direction = None
        self._id = None
        self._lag = None
        self._remote = None
        self._status_details = None
        self._local_bucket = None
        self._paused = None
        self._recovery_point = None
        self._remote_bucket = None
        self._remote_credentials = None
        self._status = None
        self.discriminator = None

        if direction is not None:
            self.direction = direction
        if id is not None:
            self.id = id
        if lag is not None:
            self.lag = lag
        if remote is not None:
            self.remote = remote
        if status_details is not None:
            self.status_details = status_details
        if local_bucket is not None:
            self.local_bucket = local_bucket
        if paused is not None:
            self.paused = paused
        if recovery_point is not None:
            self.recovery_point = recovery_point
        if remote_bucket is not None:
            self.remote_bucket = remote_bucket
        if remote_credentials is not None:
            self.remote_credentials = remote_credentials
        if status is not None:
            self.status = status

    @property
    def direction(self):
        """Gets the direction of this BucketReplicaLink.  # noqa: E501


        :return: The direction of this BucketReplicaLink.  # noqa: E501
        :rtype: Direction
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this BucketReplicaLink.


        :param direction: The direction of this BucketReplicaLink.  # noqa: E501
        :type: Direction
        """

        self._direction = direction

    @property
    def id(self):
        """Gets the id of this BucketReplicaLink.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this BucketReplicaLink.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this BucketReplicaLink.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this BucketReplicaLink.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def lag(self):
        """Gets the lag of this BucketReplicaLink.  # noqa: E501

        Duration in milliseconds that represents how far behind the replication target is from the source. This is the time difference between current time and `recovery_point`.  # noqa: E501

        :return: The lag of this BucketReplicaLink.  # noqa: E501
        :rtype: int
        """
        return self._lag

    @lag.setter
    def lag(self, lag):
        """Sets the lag of this BucketReplicaLink.

        Duration in milliseconds that represents how far behind the replication target is from the source. This is the time difference between current time and `recovery_point`.  # noqa: E501

        :param lag: The lag of this BucketReplicaLink.  # noqa: E501
        :type: int
        """

        self._lag = lag

    @property
    def remote(self):
        """Gets the remote of this BucketReplicaLink.  # noqa: E501

        Reference to a remote target.  # noqa: E501

        :return: The remote of this BucketReplicaLink.  # noqa: E501
        :rtype: FixedReferenceWithId
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this BucketReplicaLink.

        Reference to a remote target.  # noqa: E501

        :param remote: The remote of this BucketReplicaLink.  # noqa: E501
        :type: FixedReferenceWithId
        """

        self._remote = remote

    @property
    def status_details(self):
        """Gets the status_details of this BucketReplicaLink.  # noqa: E501

        Detailed information about the status of the replica link.  # noqa: E501

        :return: The status_details of this BucketReplicaLink.  # noqa: E501
        :rtype: str
        """
        return self._status_details

    @status_details.setter
    def status_details(self, status_details):
        """Sets the status_details of this BucketReplicaLink.

        Detailed information about the status of the replica link.  # noqa: E501

        :param status_details: The status_details of this BucketReplicaLink.  # noqa: E501
        :type: str
        """

        self._status_details = status_details

    @property
    def local_bucket(self):
        """Gets the local_bucket of this BucketReplicaLink.  # noqa: E501

        Reference to a local bucket.  # noqa: E501

        :return: The local_bucket of this BucketReplicaLink.  # noqa: E501
        :rtype: FixedReferenceWithId
        """
        return self._local_bucket

    @local_bucket.setter
    def local_bucket(self, local_bucket):
        """Sets the local_bucket of this BucketReplicaLink.

        Reference to a local bucket.  # noqa: E501

        :param local_bucket: The local_bucket of this BucketReplicaLink.  # noqa: E501
        :type: FixedReferenceWithId
        """

        self._local_bucket = local_bucket

    @property
    def paused(self):
        """Gets the paused of this BucketReplicaLink.  # noqa: E501

        Is the replica link paused?  # noqa: E501

        :return: The paused of this BucketReplicaLink.  # noqa: E501
        :rtype: bool
        """
        return self._paused

    @paused.setter
    def paused(self, paused):
        """Sets the paused of this BucketReplicaLink.

        Is the replica link paused?  # noqa: E501

        :param paused: The paused of this BucketReplicaLink.  # noqa: E501
        :type: bool
        """

        self._paused = paused

    @property
    def recovery_point(self):
        """Gets the recovery_point of this BucketReplicaLink.  # noqa: E501

        Time, in milliseconds since UNIX epoch, where all object changes before this time are guaranteed to have been replicated. Changes after this time may have been replicated.  # noqa: E501

        :return: The recovery_point of this BucketReplicaLink.  # noqa: E501
        :rtype: int
        """
        return self._recovery_point

    @recovery_point.setter
    def recovery_point(self, recovery_point):
        """Sets the recovery_point of this BucketReplicaLink.

        Time, in milliseconds since UNIX epoch, where all object changes before this time are guaranteed to have been replicated. Changes after this time may have been replicated.  # noqa: E501

        :param recovery_point: The recovery_point of this BucketReplicaLink.  # noqa: E501
        :type: int
        """

        self._recovery_point = recovery_point

    @property
    def remote_bucket(self):
        """Gets the remote_bucket of this BucketReplicaLink.  # noqa: E501

        Reference to a remote bucket.  # noqa: E501

        :return: The remote_bucket of this BucketReplicaLink.  # noqa: E501
        :rtype: Reference
        """
        return self._remote_bucket

    @remote_bucket.setter
    def remote_bucket(self, remote_bucket):
        """Sets the remote_bucket of this BucketReplicaLink.

        Reference to a remote bucket.  # noqa: E501

        :param remote_bucket: The remote_bucket of this BucketReplicaLink.  # noqa: E501
        :type: Reference
        """

        self._remote_bucket = remote_bucket

    @property
    def remote_credentials(self):
        """Gets the remote_credentials of this BucketReplicaLink.  # noqa: E501

        Reference to a remote-credentials object to access the remote bucket.  # noqa: E501

        :return: The remote_credentials of this BucketReplicaLink.  # noqa: E501
        :rtype: Reference
        """
        return self._remote_credentials

    @remote_credentials.setter
    def remote_credentials(self, remote_credentials):
        """Sets the remote_credentials of this BucketReplicaLink.

        Reference to a remote-credentials object to access the remote bucket.  # noqa: E501

        :param remote_credentials: The remote_credentials of this BucketReplicaLink.  # noqa: E501
        :type: Reference
        """

        self._remote_credentials = remote_credentials

    @property
    def status(self):
        """Gets the status of this BucketReplicaLink.  # noqa: E501

        Status of the replica link. Values include replicating, paused, and unhealthy.  # noqa: E501

        :return: The status of this BucketReplicaLink.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BucketReplicaLink.

        Status of the replica link. Values include replicating, paused, and unhealthy.  # noqa: E501

        :param status: The status of this BucketReplicaLink.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BucketReplicaLink, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BucketReplicaLink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.11 Python SDK

    Pure Storage FlashBlade REST 1.11 Python SDK. Compatible with REST API versions 1.0 - 1.11. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.11
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SyslogServerTest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'component_address': 'str',
        'component_name': 'str',
        'description': 'str',
        'destination': 'str',
        'details': 'str',
        'success': 'bool',
        'test_type': 'str'
    }

    attribute_map = {
        'component_address': 'component_address',
        'component_name': 'component_name',
        'description': 'description',
        'destination': 'destination',
        'details': 'details',
        'success': 'success',
        'test_type': 'test_type'
    }

    def __init__(self, component_address=None, component_name=None, description=None, destination=None, details=None, success=None, test_type=None):  # noqa: E501
        """SyslogServerTest - a model defined in Swagger"""  # noqa: E501

        self._component_address = None
        self._component_name = None
        self._description = None
        self._destination = None
        self._details = None
        self._success = None
        self._test_type = None
        self.discriminator = None

        if component_address is not None:
            self.component_address = component_address
        if component_name is not None:
            self.component_name = component_name
        if description is not None:
            self.description = description
        if destination is not None:
            self.destination = destination
        if details is not None:
            self.details = details
        if success is not None:
            self.success = success
        if test_type is not None:
            self.test_type = test_type

    @property
    def component_address(self):
        """Gets the component_address of this SyslogServerTest.  # noqa: E501

        Address of the component running the test.  # noqa: E501

        :return: The component_address of this SyslogServerTest.  # noqa: E501
        :rtype: str
        """
        return self._component_address

    @component_address.setter
    def component_address(self, component_address):
        """Sets the component_address of this SyslogServerTest.

        Address of the component running the test.  # noqa: E501

        :param component_address: The component_address of this SyslogServerTest.  # noqa: E501
        :type: str
        """

        self._component_address = component_address

    @property
    def component_name(self):
        """Gets the component_name of this SyslogServerTest.  # noqa: E501

        Name of the component running the test.  # noqa: E501

        :return: The component_name of this SyslogServerTest.  # noqa: E501
        :rtype: str
        """
        return self._component_name

    @component_name.setter
    def component_name(self, component_name):
        """Sets the component_name of this SyslogServerTest.

        Name of the component running the test.  # noqa: E501

        :param component_name: The component_name of this SyslogServerTest.  # noqa: E501
        :type: str
        """

        self._component_name = component_name

    @property
    def description(self):
        """Gets the description of this SyslogServerTest.  # noqa: E501

        What the test is doing.  # noqa: E501

        :return: The description of this SyslogServerTest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this SyslogServerTest.

        What the test is doing.  # noqa: E501

        :param description: The description of this SyslogServerTest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def destination(self):
        """Gets the destination of this SyslogServerTest.  # noqa: E501

        The URI of the target syslog server being tested.  # noqa: E501

        :return: The destination of this SyslogServerTest.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this SyslogServerTest.

        The URI of the target syslog server being tested.  # noqa: E501

        :param destination: The destination of this SyslogServerTest.  # noqa: E501
        :type: str
        """

        self._destination = destination

    @property
    def details(self):
        """Gets the details of this SyslogServerTest.  # noqa: E501

        The output of the test.  # noqa: E501

        :return: The details of this SyslogServerTest.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this SyslogServerTest.

        The output of the test.  # noqa: E501

        :param details: The details of this SyslogServerTest.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def success(self):
        """Gets the success of this SyslogServerTest.  # noqa: E501

        Returns a value of `true` if the specified test succeeded. Returns a value of `false` if the specified test failed.  # noqa: E501

        :return: The success of this SyslogServerTest.  # noqa: E501
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this SyslogServerTest.

        Returns a value of `true` if the specified test succeeded. Returns a value of `false` if the specified test failed.  # noqa: E501

        :param success: The success of this SyslogServerTest.  # noqa: E501
        :type: bool
        """

        self._success = success

    @property
    def test_type(self):
        """Gets the test_type of this SyslogServerTest.  # noqa: E501

        Displays the type of test being performed.  The returned values are determined by the syslog connection being tested and its configuration. Possible values include `connecting` and `message-sending`.  # noqa: E501

        :return: The test_type of this SyslogServerTest.  # noqa: E501
        :rtype: str
        """
        return self._test_type

    @test_type.setter
    def test_type(self, test_type):
        """Sets the test_type of this SyslogServerTest.

        Displays the type of test being performed.  The returned values are determined by the syslog connection being tested and its configuration. Possible values include `connecting` and `message-sending`.  # noqa: E501

        :param test_type: The test_type of this SyslogServerTest.  # noqa: E501
        :type: str
        """

        self._test_type = test_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SyslogServerTest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyslogServerTest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.4 Python SDK

    Pure Storage FlashBlade REST 1.4 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.4
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class LinkAggregationGroup(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'lag_speed': 'int',
        'mac_address': 'str',
        'ports': 'list[Reference]',
        'port_speed': 'int',
        'status': 'str'
    }

    attribute_map = {
        'name': 'name',
        'lag_speed': 'lag_speed',
        'mac_address': 'mac_address',
        'ports': 'ports',
        'port_speed': 'port_speed',
        'status': 'status'
    }

    def __init__(self, name=None, lag_speed=None, mac_address=None, ports=None, port_speed=None, status=None):  # noqa: E501
        """LinkAggregationGroup - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._lag_speed = None
        self._mac_address = None
        self._ports = None
        self._port_speed = None
        self._status = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if lag_speed is not None:
            self.lag_speed = lag_speed
        if mac_address is not None:
            self.mac_address = mac_address
        if ports is not None:
            self.ports = ports
        if port_speed is not None:
            self.port_speed = port_speed
        if status is not None:
            self.status = status

    @property
    def name(self):
        """Gets the name of this LinkAggregationGroup.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this LinkAggregationGroup.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this LinkAggregationGroup.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this LinkAggregationGroup.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def lag_speed(self):
        """Gets the lag_speed of this LinkAggregationGroup.  # noqa: E501

        Combined speed of all ports in the LAG in bits-per-second.  # noqa: E501

        :return: The lag_speed of this LinkAggregationGroup.  # noqa: E501
        :rtype: int
        """
        return self._lag_speed

    @lag_speed.setter
    def lag_speed(self, lag_speed):
        """Sets the lag_speed of this LinkAggregationGroup.

        Combined speed of all ports in the LAG in bits-per-second.  # noqa: E501

        :param lag_speed: The lag_speed of this LinkAggregationGroup.  # noqa: E501
        :type: int
        """

        self._lag_speed = lag_speed

    @property
    def mac_address(self):
        """Gets the mac_address of this LinkAggregationGroup.  # noqa: E501

        Unique MAC address assigned to the LAG  # noqa: E501

        :return: The mac_address of this LinkAggregationGroup.  # noqa: E501
        :rtype: str
        """
        return self._mac_address

    @mac_address.setter
    def mac_address(self, mac_address):
        """Sets the mac_address of this LinkAggregationGroup.

        Unique MAC address assigned to the LAG  # noqa: E501

        :param mac_address: The mac_address of this LinkAggregationGroup.  # noqa: E501
        :type: str
        """
        if mac_address is not None and not re.search(r'^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$', mac_address):  # noqa: E501
            raise ValueError(r"Invalid value for `mac_address`, must be a follow pattern or equal to `/^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/`")  # noqa: E501

        self._mac_address = mac_address

    @property
    def ports(self):
        """Gets the ports of this LinkAggregationGroup.  # noqa: E501

        Ports associated with the LAG  # noqa: E501

        :return: The ports of this LinkAggregationGroup.  # noqa: E501
        :rtype: list[Reference]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this LinkAggregationGroup.

        Ports associated with the LAG  # noqa: E501

        :param ports: The ports of this LinkAggregationGroup.  # noqa: E501
        :type: list[Reference]
        """

        self._ports = ports

    @property
    def port_speed(self):
        """Gets the port_speed of this LinkAggregationGroup.  # noqa: E501

        Configured speed of each port in the LAG in bits-per-second  # noqa: E501

        :return: The port_speed of this LinkAggregationGroup.  # noqa: E501
        :rtype: int
        """
        return self._port_speed

    @port_speed.setter
    def port_speed(self, port_speed):
        """Sets the port_speed of this LinkAggregationGroup.

        Configured speed of each port in the LAG in bits-per-second  # noqa: E501

        :param port_speed: The port_speed of this LinkAggregationGroup.  # noqa: E501
        :type: int
        """

        self._port_speed = port_speed

    @property
    def status(self):
        """Gets the status of this LinkAggregationGroup.  # noqa: E501

        Health status of the LAG. Possible values are critical, healthy, identifying, unclaimed, unhealthy, unrecognized and unused.  # noqa: E501

        :return: The status of this LinkAggregationGroup.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this LinkAggregationGroup.

        Health status of the LAG. Possible values are critical, healthy, identifying, unclaimed, unhealthy, unrecognized and unused.  # noqa: E501

        :param status: The status of this LinkAggregationGroup.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LinkAggregationGroup, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LinkAggregationGroup):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class SyslogServer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'id': 'str',
        'uri': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'uri': 'uri'
    }

    def __init__(self, name=None, id=None, uri=None):  # noqa: E501
        """SyslogServer - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._id = None
        self._uri = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if uri is not None:
            self.uri = uri

    @property
    def name(self):
        """Gets the name of this SyslogServer.  # noqa: E501

        The name of the object  # noqa: E501

        :return: The name of this SyslogServer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SyslogServer.

        The name of the object  # noqa: E501

        :param name: The name of this SyslogServer.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this SyslogServer.  # noqa: E501

        A unique ID chosen by the system. Cannot change.  # noqa: E501

        :return: The id of this SyslogServer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SyslogServer.

        A unique ID chosen by the system. Cannot change.  # noqa: E501

        :param id: The id of this SyslogServer.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def uri(self):
        """Gets the uri of this SyslogServer.  # noqa: E501

        The `URI` of the syslog server in the format `PROTOCOL://HOSTNAME:PORT`.  # noqa: E501

        :return: The uri of this SyslogServer.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this SyslogServer.

        The `URI` of the syslog server in the format `PROTOCOL://HOSTNAME:PORT`.  # noqa: E501

        :param uri: The uri of this SyslogServer.  # noqa: E501
        :type: str
        """

        self._uri = uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SyslogServer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyslogServer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.10 Python SDK

    Pure Storage FlashBlade REST 1.10 Python SDK. Compatible with REST API versions 1.0 - 1.10. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.10
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FileSystemSnapshot(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'id': 'str',
        'destroyed': 'bool',
        'owner': 'Reference',
        'owner_destroyed': 'bool',
        'policy': 'LocationReference',
        'source': 'str',
        'source_destroyed': 'bool',
        'source_id': 'str',
        'source_is_local': 'bool',
        'source_location': 'Reference',
        'source_display_name': 'str',
        'suffix': 'str',
        'time_remaining': 'int'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'destroyed': 'destroyed',
        'owner': 'owner',
        'owner_destroyed': 'owner_destroyed',
        'policy': 'policy',
        'source': 'source',
        'source_destroyed': 'source_destroyed',
        'source_id': 'source_id',
        'source_is_local': 'source_is_local',
        'source_location': 'source_location',
        'source_display_name': 'source_display_name',
        'suffix': 'suffix',
        'time_remaining': 'time_remaining'
    }

    def __init__(self, name=None, id=None, destroyed=None, owner=None, owner_destroyed=None, policy=None, source=None, source_destroyed=None, source_id=None, source_is_local=None, source_location=None, source_display_name=None, suffix=None, time_remaining=None):  # noqa: E501
        """FileSystemSnapshot - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._id = None
        self._destroyed = None
        self._owner = None
        self._owner_destroyed = None
        self._policy = None
        self._source = None
        self._source_destroyed = None
        self._source_id = None
        self._source_is_local = None
        self._source_location = None
        self._source_display_name = None
        self._suffix = None
        self._time_remaining = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if id is not None:
            self.id = id
        if destroyed is not None:
            self.destroyed = destroyed
        if owner is not None:
            self.owner = owner
        if owner_destroyed is not None:
            self.owner_destroyed = owner_destroyed
        if policy is not None:
            self.policy = policy
        if source is not None:
            self.source = source
        if source_destroyed is not None:
            self.source_destroyed = source_destroyed
        if source_id is not None:
            self.source_id = source_id
        if source_is_local is not None:
            self.source_is_local = source_is_local
        if source_location is not None:
            self.source_location = source_location
        if source_display_name is not None:
            self.source_display_name = source_display_name
        if suffix is not None:
            self.suffix = suffix
        if time_remaining is not None:
            self.time_remaining = time_remaining

    @property
    def name(self):
        """Gets the name of this FileSystemSnapshot.  # noqa: E501

        The name of the object  # noqa: E501

        :return: The name of this FileSystemSnapshot.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileSystemSnapshot.

        The name of the object  # noqa: E501

        :param name: The name of this FileSystemSnapshot.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def id(self):
        """Gets the id of this FileSystemSnapshot.  # noqa: E501

        A unique ID chosen by the system. Cannot change.  # noqa: E501

        :return: The id of this FileSystemSnapshot.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FileSystemSnapshot.

        A unique ID chosen by the system. Cannot change.  # noqa: E501

        :param id: The id of this FileSystemSnapshot.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def destroyed(self):
        """Gets the destroyed of this FileSystemSnapshot.  # noqa: E501

        Is the file system snapshot destroyed? False by default.  # noqa: E501

        :return: The destroyed of this FileSystemSnapshot.  # noqa: E501
        :rtype: bool
        """
        return self._destroyed

    @destroyed.setter
    def destroyed(self, destroyed):
        """Sets the destroyed of this FileSystemSnapshot.

        Is the file system snapshot destroyed? False by default.  # noqa: E501

        :param destroyed: The destroyed of this FileSystemSnapshot.  # noqa: E501
        :type: bool
        """

        self._destroyed = destroyed

    @property
    def owner(self):
        """Gets the owner of this FileSystemSnapshot.  # noqa: E501

        A reference to the file system that owns this snapshot. If the owner is destroyed, this will be destroyed.  # noqa: E501

        :return: The owner of this FileSystemSnapshot.  # noqa: E501
        :rtype: Reference
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this FileSystemSnapshot.

        A reference to the file system that owns this snapshot. If the owner is destroyed, this will be destroyed.  # noqa: E501

        :param owner: The owner of this FileSystemSnapshot.  # noqa: E501
        :type: Reference
        """

        self._owner = owner

    @property
    def owner_destroyed(self):
        """Gets the owner_destroyed of this FileSystemSnapshot.  # noqa: E501

        Is the owning file system destroyed?  # noqa: E501

        :return: The owner_destroyed of this FileSystemSnapshot.  # noqa: E501
        :rtype: bool
        """
        return self._owner_destroyed

    @owner_destroyed.setter
    def owner_destroyed(self, owner_destroyed):
        """Sets the owner_destroyed of this FileSystemSnapshot.

        Is the owning file system destroyed?  # noqa: E501

        :param owner_destroyed: The owner_destroyed of this FileSystemSnapshot.  # noqa: E501
        :type: bool
        """

        self._owner_destroyed = owner_destroyed

    @property
    def policy(self):
        """Gets the policy of this FileSystemSnapshot.  # noqa: E501

        A reference to the associated policy.  # noqa: E501

        :return: The policy of this FileSystemSnapshot.  # noqa: E501
        :rtype: LocationReference
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this FileSystemSnapshot.

        A reference to the associated policy.  # noqa: E501

        :param policy: The policy of this FileSystemSnapshot.  # noqa: E501
        :type: LocationReference
        """

        self._policy = policy

    @property
    def source(self):
        """Gets the source of this FileSystemSnapshot.  # noqa: E501

        The name of the file system that was the source of the data in this snapshot. Normally this is the same as the owner, but if the snapshot is replicated, the source is the original file system.  # noqa: E501

        :return: The source of this FileSystemSnapshot.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this FileSystemSnapshot.

        The name of the file system that was the source of the data in this snapshot. Normally this is the same as the owner, but if the snapshot is replicated, the source is the original file system.  # noqa: E501

        :param source: The source of this FileSystemSnapshot.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def source_destroyed(self):
        """Gets the source_destroyed of this FileSystemSnapshot.  # noqa: E501

        Deprecated. Use `owner_destroyed`. Is the owning file system destroyed?  # noqa: E501

        :return: The source_destroyed of this FileSystemSnapshot.  # noqa: E501
        :rtype: bool
        """
        return self._source_destroyed

    @source_destroyed.setter
    def source_destroyed(self, source_destroyed):
        """Sets the source_destroyed of this FileSystemSnapshot.

        Deprecated. Use `owner_destroyed`. Is the owning file system destroyed?  # noqa: E501

        :param source_destroyed: The source_destroyed of this FileSystemSnapshot.  # noqa: E501
        :type: bool
        """

        self._source_destroyed = source_destroyed

    @property
    def source_id(self):
        """Gets the source_id of this FileSystemSnapshot.  # noqa: E501

        The unique global ID of the source file system.  # noqa: E501

        :return: The source_id of this FileSystemSnapshot.  # noqa: E501
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """Sets the source_id of this FileSystemSnapshot.

        The unique global ID of the source file system.  # noqa: E501

        :param source_id: The source_id of this FileSystemSnapshot.  # noqa: E501
        :type: str
        """

        self._source_id = source_id

    @property
    def source_is_local(self):
        """Gets the source_is_local of this FileSystemSnapshot.  # noqa: E501

        Is the source of this file system snapshot on the local array?  # noqa: E501

        :return: The source_is_local of this FileSystemSnapshot.  # noqa: E501
        :rtype: bool
        """
        return self._source_is_local

    @source_is_local.setter
    def source_is_local(self, source_is_local):
        """Sets the source_is_local of this FileSystemSnapshot.

        Is the source of this file system snapshot on the local array?  # noqa: E501

        :param source_is_local: The source_is_local of this FileSystemSnapshot.  # noqa: E501
        :type: bool
        """

        self._source_is_local = source_is_local

    @property
    def source_location(self):
        """Gets the source_location of this FileSystemSnapshot.  # noqa: E501

        A reference to the source array.  # noqa: E501

        :return: The source_location of this FileSystemSnapshot.  # noqa: E501
        :rtype: Reference
        """
        return self._source_location

    @source_location.setter
    def source_location(self, source_location):
        """Sets the source_location of this FileSystemSnapshot.

        A reference to the source array.  # noqa: E501

        :param source_location: The source_location of this FileSystemSnapshot.  # noqa: E501
        :type: Reference
        """

        self._source_location = source_location

    @property
    def source_display_name(self):
        """Gets the source_display_name of this FileSystemSnapshot.  # noqa: E501

        Full name of the source with remote array information. Response will be same as source for local file system snapshots.  # noqa: E501

        :return: The source_display_name of this FileSystemSnapshot.  # noqa: E501
        :rtype: str
        """
        return self._source_display_name

    @source_display_name.setter
    def source_display_name(self, source_display_name):
        """Sets the source_display_name of this FileSystemSnapshot.

        Full name of the source with remote array information. Response will be same as source for local file system snapshots.  # noqa: E501

        :param source_display_name: The source_display_name of this FileSystemSnapshot.  # noqa: E501
        :type: str
        """

        self._source_display_name = source_display_name

    @property
    def suffix(self):
        """Gets the suffix of this FileSystemSnapshot.  # noqa: E501

        The suffix of the snapshot, e.g., snap1.  # noqa: E501

        :return: The suffix of this FileSystemSnapshot.  # noqa: E501
        :rtype: str
        """
        return self._suffix

    @suffix.setter
    def suffix(self, suffix):
        """Sets the suffix of this FileSystemSnapshot.

        The suffix of the snapshot, e.g., snap1.  # noqa: E501

        :param suffix: The suffix of this FileSystemSnapshot.  # noqa: E501
        :type: str
        """

        self._suffix = suffix

    @property
    def time_remaining(self):
        """Gets the time_remaining of this FileSystemSnapshot.  # noqa: E501

        Time in milliseconds before the file system snapshot is eradicated. Null if not destroyed.  # noqa: E501

        :return: The time_remaining of this FileSystemSnapshot.  # noqa: E501
        :rtype: int
        """
        return self._time_remaining

    @time_remaining.setter
    def time_remaining(self, time_remaining):
        """Sets the time_remaining of this FileSystemSnapshot.

        Time in milliseconds before the file system snapshot is eradicated. Null if not destroyed.  # noqa: E501

        :param time_remaining: The time_remaining of this FileSystemSnapshot.  # noqa: E501
        :type: int
        """

        self._time_remaining = time_remaining

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FileSystemSnapshot, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileSystemSnapshot):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.9 Python SDK

    Pure Storage FlashBlade REST 1.9 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.9
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class DirectoryService(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'base_dn': 'str',
        'bind_password': 'str',
        'bind_user': 'str',
        'ca_certificate': 'Reference',
        'ca_certificate_group': 'Reference',
        'enabled': 'bool',
        'management': 'DirectoryserviceManagement',
        'nfs': 'DirectoryserviceNfs',
        'services': 'list[str]',
        'smb': 'DirectoryserviceSmb',
        'uris': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'base_dn': 'base_dn',
        'bind_password': 'bind_password',
        'bind_user': 'bind_user',
        'ca_certificate': 'ca_certificate',
        'ca_certificate_group': 'ca_certificate_group',
        'enabled': 'enabled',
        'management': 'management',
        'nfs': 'nfs',
        'services': 'services',
        'smb': 'smb',
        'uris': 'uris'
    }

    def __init__(self, id=None, name=None, base_dn=None, bind_password=None, bind_user=None, ca_certificate=None, ca_certificate_group=None, enabled=None, management=None, nfs=None, services=None, smb=None, uris=None):  # noqa: E501
        """DirectoryService - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._base_dn = None
        self._bind_password = None
        self._bind_user = None
        self._ca_certificate = None
        self._ca_certificate_group = None
        self._enabled = None
        self._management = None
        self._nfs = None
        self._services = None
        self._smb = None
        self._uris = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if base_dn is not None:
            self.base_dn = base_dn
        if bind_password is not None:
            self.bind_password = bind_password
        if bind_user is not None:
            self.bind_user = bind_user
        if ca_certificate is not None:
            self.ca_certificate = ca_certificate
        if ca_certificate_group is not None:
            self.ca_certificate_group = ca_certificate_group
        if enabled is not None:
            self.enabled = enabled
        if management is not None:
            self.management = management
        if nfs is not None:
            self.nfs = nfs
        if services is not None:
            self.services = services
        if smb is not None:
            self.smb = smb
        if uris is not None:
            self.uris = uris

    @property
    def id(self):
        """Gets the id of this DirectoryService.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this DirectoryService.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DirectoryService.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this DirectoryService.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DirectoryService.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this DirectoryService.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DirectoryService.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this DirectoryService.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def base_dn(self):
        """Gets the base_dn of this DirectoryService.  # noqa: E501

        Base of the Distinguished Name (DN) of the directory service groups.  # noqa: E501

        :return: The base_dn of this DirectoryService.  # noqa: E501
        :rtype: str
        """
        return self._base_dn

    @base_dn.setter
    def base_dn(self, base_dn):
        """Sets the base_dn of this DirectoryService.

        Base of the Distinguished Name (DN) of the directory service groups.  # noqa: E501

        :param base_dn: The base_dn of this DirectoryService.  # noqa: E501
        :type: str
        """

        self._base_dn = base_dn

    @property
    def bind_password(self):
        """Gets the bind_password of this DirectoryService.  # noqa: E501

        Obfuscated password used to query the directory.  # noqa: E501

        :return: The bind_password of this DirectoryService.  # noqa: E501
        :rtype: str
        """
        return self._bind_password

    @bind_password.setter
    def bind_password(self, bind_password):
        """Sets the bind_password of this DirectoryService.

        Obfuscated password used to query the directory.  # noqa: E501

        :param bind_password: The bind_password of this DirectoryService.  # noqa: E501
        :type: str
        """

        self._bind_password = bind_password

    @property
    def bind_user(self):
        """Gets the bind_user of this DirectoryService.  # noqa: E501

        Username used to query the directory.  # noqa: E501

        :return: The bind_user of this DirectoryService.  # noqa: E501
        :rtype: str
        """
        return self._bind_user

    @bind_user.setter
    def bind_user(self, bind_user):
        """Sets the bind_user of this DirectoryService.

        Username used to query the directory.  # noqa: E501

        :param bind_user: The bind_user of this DirectoryService.  # noqa: E501
        :type: str
        """

        self._bind_user = bind_user

    @property
    def ca_certificate(self):
        """Gets the ca_certificate of this DirectoryService.  # noqa: E501

        CA certificate used to validate the authenticity of the configured servers.  # noqa: E501

        :return: The ca_certificate of this DirectoryService.  # noqa: E501
        :rtype: Reference
        """
        return self._ca_certificate

    @ca_certificate.setter
    def ca_certificate(self, ca_certificate):
        """Sets the ca_certificate of this DirectoryService.

        CA certificate used to validate the authenticity of the configured servers.  # noqa: E501

        :param ca_certificate: The ca_certificate of this DirectoryService.  # noqa: E501
        :type: Reference
        """

        self._ca_certificate = ca_certificate

    @property
    def ca_certificate_group(self):
        """Gets the ca_certificate_group of this DirectoryService.  # noqa: E501

        Certificate group containing CA certificates that can be used to validate the authenticity of the configured servers.  # noqa: E501

        :return: The ca_certificate_group of this DirectoryService.  # noqa: E501
        :rtype: Reference
        """
        return self._ca_certificate_group

    @ca_certificate_group.setter
    def ca_certificate_group(self, ca_certificate_group):
        """Sets the ca_certificate_group of this DirectoryService.

        Certificate group containing CA certificates that can be used to validate the authenticity of the configured servers.  # noqa: E501

        :param ca_certificate_group: The ca_certificate_group of this DirectoryService.  # noqa: E501
        :type: Reference
        """

        self._ca_certificate_group = ca_certificate_group

    @property
    def enabled(self):
        """Gets the enabled of this DirectoryService.  # noqa: E501

        Is the directory service enabled or not?  # noqa: E501

        :return: The enabled of this DirectoryService.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this DirectoryService.

        Is the directory service enabled or not?  # noqa: E501

        :param enabled: The enabled of this DirectoryService.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def management(self):
        """Gets the management of this DirectoryService.  # noqa: E501


        :return: The management of this DirectoryService.  # noqa: E501
        :rtype: DirectoryserviceManagement
        """
        return self._management

    @management.setter
    def management(self, management):
        """Sets the management of this DirectoryService.


        :param management: The management of this DirectoryService.  # noqa: E501
        :type: DirectoryserviceManagement
        """

        self._management = management

    @property
    def nfs(self):
        """Gets the nfs of this DirectoryService.  # noqa: E501


        :return: The nfs of this DirectoryService.  # noqa: E501
        :rtype: DirectoryserviceNfs
        """
        return self._nfs

    @nfs.setter
    def nfs(self, nfs):
        """Sets the nfs of this DirectoryService.


        :param nfs: The nfs of this DirectoryService.  # noqa: E501
        :type: DirectoryserviceNfs
        """

        self._nfs = nfs

    @property
    def services(self):
        """Gets the services of this DirectoryService.  # noqa: E501

        Services that the directory service configuration is used for.  # noqa: E501

        :return: The services of this DirectoryService.  # noqa: E501
        :rtype: list[str]
        """
        return self._services

    @services.setter
    def services(self, services):
        """Sets the services of this DirectoryService.

        Services that the directory service configuration is used for.  # noqa: E501

        :param services: The services of this DirectoryService.  # noqa: E501
        :type: list[str]
        """

        self._services = services

    @property
    def smb(self):
        """Gets the smb of this DirectoryService.  # noqa: E501


        :return: The smb of this DirectoryService.  # noqa: E501
        :rtype: DirectoryserviceSmb
        """
        return self._smb

    @smb.setter
    def smb(self, smb):
        """Sets the smb of this DirectoryService.


        :param smb: The smb of this DirectoryService.  # noqa: E501
        :type: DirectoryserviceSmb
        """

        self._smb = smb

    @property
    def uris(self):
        """Gets the uris of this DirectoryService.  # noqa: E501

        List of URIs for the configured directory servers.  # noqa: E501

        :return: The uris of this DirectoryService.  # noqa: E501
        :rtype: list[str]
        """
        return self._uris

    @uris.setter
    def uris(self, uris):
        """Sets the uris of this DirectoryService.

        List of URIs for the configured directory servers.  # noqa: E501

        :param uris: The uris of this DirectoryService.  # noqa: E501
        :type: list[str]
        """

        self._uris = uris

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DirectoryService, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DirectoryService):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.0 Python SDK

    Pure Storage FlashBlade REST 1.0 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.0
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import purity_fb_1dot0
from purity_fb_1dot0.rest import ApiException
from purity_fb_1dot0.apis.file_system_snapshots_api import FileSystemSnapshotsApi


class TestFileSystemSnapshotsApi(unittest.TestCase):
    """ FileSystemSnapshotsApi unit test stubs """

    def setUp(self):
        self.api = purity_fb_1dot0.apis.file_system_snapshots_api.FileSystemSnapshotsApi()

    def tearDown(self):
        pass

    def test_create_file_system_snapshots(self):
        """
        Test case for create_file_system_snapshots

        
        """
        pass

    def test_list_file_system_snapshots(self):
        """
        Test case for list_file_system_snapshots

        
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.12 Python SDK

    Pure Storage FlashBlade REST 1.12 Python SDK. Compatible with REST API versions 1.0 - 1.12. Developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.12
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ApiClientResp(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'max_role': 'FixedReferenceNoResourceType',
        'issuer': 'str',
        'public_key': 'str',
        'key_id': 'str',
        'enabled': 'bool',
        'access_token_ttl_in_ms': 'int'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'max_role': 'max_role',
        'issuer': 'issuer',
        'public_key': 'public_key',
        'key_id': 'key_id',
        'enabled': 'enabled',
        'access_token_ttl_in_ms': 'access_token_ttl_in_ms'
    }

    def __init__(self, id=None, name=None, max_role=None, issuer=None, public_key=None, key_id=None, enabled=None, access_token_ttl_in_ms=None):  # noqa: E501
        """ApiClientResp - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._max_role = None
        self._issuer = None
        self._public_key = None
        self._key_id = None
        self._enabled = None
        self._access_token_ttl_in_ms = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if max_role is not None:
            self.max_role = max_role
        if issuer is not None:
            self.issuer = issuer
        if public_key is not None:
            self.public_key = public_key
        if key_id is not None:
            self.key_id = key_id
        if enabled is not None:
            self.enabled = enabled
        if access_token_ttl_in_ms is not None:
            self.access_token_ttl_in_ms = access_token_ttl_in_ms

    @property
    def id(self):
        """Gets the id of this ApiClientResp.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this ApiClientResp.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ApiClientResp.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this ApiClientResp.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ApiClientResp.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this ApiClientResp.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ApiClientResp.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this ApiClientResp.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def max_role(self):
        """Gets the max_role of this ApiClientResp.  # noqa: E501

        The maximum role allowed for ID Tokens issued by this API client. The bearer of an access token will be authorized to perform actions within the intersection of this max_role and the role of the array user specified as the JWT sub (subject) claim. Valid max_role values are readonly, ops_admin, array_admin, and storage_admin. Users with the readonly (Read Only) role can perform operations that convey the state of the array. Read Only users cannot alter the state of the array. Users with the ops_admin (Ops Admin) role can perform the same operations as Read Only users plus enable and disable remote assistance sessions. Ops Admin users cannot alter the state of the array. Users with the storage_admin (Storage Admin) role can perform the same operations as Read Only users plus storage related operations, such as administering volumes, hosts, and host groups. Storage Admin users cannot perform operations that deal with global and system configurations. Users with the array_admin (Array Admin) role can perform the same operations as Storage Admin users plus array-wide changes dealing with global and system configurations. In other words, Array Admin users can perform all operations.  # noqa: E501

        :return: The max_role of this ApiClientResp.  # noqa: E501
        :rtype: FixedReferenceNoResourceType
        """
        return self._max_role

    @max_role.setter
    def max_role(self, max_role):
        """Sets the max_role of this ApiClientResp.

        The maximum role allowed for ID Tokens issued by this API client. The bearer of an access token will be authorized to perform actions within the intersection of this max_role and the role of the array user specified as the JWT sub (subject) claim. Valid max_role values are readonly, ops_admin, array_admin, and storage_admin. Users with the readonly (Read Only) role can perform operations that convey the state of the array. Read Only users cannot alter the state of the array. Users with the ops_admin (Ops Admin) role can perform the same operations as Read Only users plus enable and disable remote assistance sessions. Ops Admin users cannot alter the state of the array. Users with the storage_admin (Storage Admin) role can perform the same operations as Read Only users plus storage related operations, such as administering volumes, hosts, and host groups. Storage Admin users cannot perform operations that deal with global and system configurations. Users with the array_admin (Array Admin) role can perform the same operations as Storage Admin users plus array-wide changes dealing with global and system configurations. In other words, Array Admin users can perform all operations.  # noqa: E501

        :param max_role: The max_role of this ApiClientResp.  # noqa: E501
        :type: FixedReferenceNoResourceType
        """

        self._max_role = max_role

    @property
    def issuer(self):
        """Gets the issuer of this ApiClientResp.  # noqa: E501

        The name of the identity provider that will be issuing ID Tokens for this API client. This string represents the JWT iss (issuer) claim in ID Tokens issued for this API client.  # noqa: E501

        :return: The issuer of this ApiClientResp.  # noqa: E501
        :rtype: str
        """
        return self._issuer

    @issuer.setter
    def issuer(self, issuer):
        """Sets the issuer of this ApiClientResp.

        The name of the identity provider that will be issuing ID Tokens for this API client. This string represents the JWT iss (issuer) claim in ID Tokens issued for this API client.  # noqa: E501

        :param issuer: The issuer of this ApiClientResp.  # noqa: E501
        :type: str
        """

        self._issuer = issuer

    @property
    def public_key(self):
        """Gets the public_key of this ApiClientResp.  # noqa: E501

        The API client's PEM formatted (Base64 encoded) RSA public key.  # noqa: E501

        :return: The public_key of this ApiClientResp.  # noqa: E501
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """Sets the public_key of this ApiClientResp.

        The API client's PEM formatted (Base64 encoded) RSA public key.  # noqa: E501

        :param public_key: The public_key of this ApiClientResp.  # noqa: E501
        :type: str
        """

        self._public_key = public_key

    @property
    def key_id(self):
        """Gets the key_id of this ApiClientResp.  # noqa: E501

        The unique identifier for the associated public key of this API client. This string must match the JWT kid (key ID) claim in ID Tokens issued for this API client.  # noqa: E501

        :return: The key_id of this ApiClientResp.  # noqa: E501
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """Sets the key_id of this ApiClientResp.

        The unique identifier for the associated public key of this API client. This string must match the JWT kid (key ID) claim in ID Tokens issued for this API client.  # noqa: E501

        :param key_id: The key_id of this ApiClientResp.  # noqa: E501
        :type: str
        """

        self._key_id = key_id

    @property
    def enabled(self):
        """Gets the enabled of this ApiClientResp.  # noqa: E501

        If true, the API client is permitted to exchange ID Tokens for access tokens. API clients are disabled by default.  # noqa: E501

        :return: The enabled of this ApiClientResp.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ApiClientResp.

        If true, the API client is permitted to exchange ID Tokens for access tokens. API clients are disabled by default.  # noqa: E501

        :param enabled: The enabled of this ApiClientResp.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    @property
    def access_token_ttl_in_ms(self):
        """Gets the access_token_ttl_in_ms of this ApiClientResp.  # noqa: E501

        The requested TTL (Time To Live) length of time for the exchanged access token. Measured in milliseconds.  # noqa: E501

        :return: The access_token_ttl_in_ms of this ApiClientResp.  # noqa: E501
        :rtype: int
        """
        return self._access_token_ttl_in_ms

    @access_token_ttl_in_ms.setter
    def access_token_ttl_in_ms(self, access_token_ttl_in_ms):
        """Sets the access_token_ttl_in_ms of this ApiClientResp.

        The requested TTL (Time To Live) length of time for the exchanged access token. Measured in milliseconds.  # noqa: E501

        :param access_token_ttl_in_ms: The access_token_ttl_in_ms of this ApiClientResp.  # noqa: E501
        :type: int
        """

        self._access_token_ttl_in_ms = access_token_ttl_in_ms

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ApiClientResp, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ApiClientResp):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.5 Python SDK

    Pure Storage FlashBlade REST 1.5 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.5
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResourceRule(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'keep_for': 'int',
        'every': 'int',
        'at': 'int'
    }

    attribute_map = {
        'keep_for': 'keep_for',
        'every': 'every',
        'at': 'at'
    }

    def __init__(self, keep_for=None, every=None, at=None):  # noqa: E501
        """ResourceRule - a model defined in Swagger"""  # noqa: E501

        self._keep_for = None
        self._every = None
        self._at = None
        self.discriminator = None

        if keep_for is not None:
            self.keep_for = keep_for
        if every is not None:
            self.every = every
        if at is not None:
            self.at = at

    @property
    def keep_for(self):
        """Gets the keep_for of this ResourceRule.  # noqa: E501

        how long we keep the snapshots  # noqa: E501

        :return: The keep_for of this ResourceRule.  # noqa: E501
        :rtype: int
        """
        return self._keep_for

    @keep_for.setter
    def keep_for(self, keep_for):
        """Sets the keep_for of this ResourceRule.

        how long we keep the snapshots  # noqa: E501

        :param keep_for: The keep_for of this ResourceRule.  # noqa: E501
        :type: int
        """

        self._keep_for = keep_for

    @property
    def every(self):
        """Gets the every of this ResourceRule.  # noqa: E501

        interval between we create a snapshot  # noqa: E501

        :return: The every of this ResourceRule.  # noqa: E501
        :rtype: int
        """
        return self._every

    @every.setter
    def every(self, every):
        """Sets the every of this ResourceRule.

        interval between we create a snapshot  # noqa: E501

        :param every: The every of this ResourceRule.  # noqa: E501
        :type: int
        """

        self._every = every

    @property
    def at(self):
        """Gets the at of this ResourceRule.  # noqa: E501

        time during the day, only valid if frequency is in days  # noqa: E501

        :return: The at of this ResourceRule.  # noqa: E501
        :rtype: int
        """
        return self._at

    @at.setter
    def at(self, at):
        """Sets the at of this ResourceRule.

        time during the day, only valid if frequency is in days  # noqa: E501

        :param at: The at of this ResourceRule.  # noqa: E501
        :type: int
        """

        self._at = at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourceRule, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceRule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# import apis into api package
from .admins_api import AdminsApi
from .alert_watchers_api import AlertWatchersApi
from .alerts_api import AlertsApi
from .arrays_api import ArraysApi
from .authentication_api import AuthenticationApi
from .blade_api import BladeApi
from .certificates_api import CertificatesApi
from .dns_api import DnsApi
from .file_system_snapshots_api import FileSystemSnapshotsApi
from .file_systems_api import FileSystemsApi
from .hardware_api import HardwareApi
from .version_api import VersionApi



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.0 Python SDK

    Pure Storage FlashBlade REST 1.0 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.0
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into sdk package
from .models.error_response import ErrorResponse
from .models.file_system import FileSystem
from .models.file_system_response import FileSystemResponse
from .models.file_system_snapshot import FileSystemSnapshot
from .models.file_system_snapshot_response import FileSystemSnapshotResponse
from .models.login_response import LoginResponse
from .models.nfs_rule import NfsRule
from .models.object_response import ObjectResponse
from .models.pagination_info import PaginationInfo
from .models.protocol_rule import ProtocolRule
from .models.pure_error import PureError
from .models.pure_object import PureObject
from .models.snapshot_suffix import SnapshotSuffix
from .models.space import Space
from .models.version_response import VersionResponse

# import apis into sdk package
from .apis.authentication_api import AuthenticationApi
from .apis.file_system_snapshots_api import FileSystemSnapshotsApi
from .apis.file_systems_api import FileSystemsApi
from .apis.version_api import VersionApi

# import ApiClient
from .api_client import ApiClient

from .configuration import Configuration

configuration = Configuration()



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.8 Python SDK

    Pure Storage FlashBlade REST 1.8 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.8
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ClientPerformance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'bytes_per_op': 'int',
        'bytes_per_read': 'int',
        'bytes_per_write': 'int',
        'others_per_sec': 'int',
        'read_bytes_per_sec': 'int',
        'reads_per_sec': 'int',
        'time': 'int',
        'usec_per_other_op': 'int',
        'usec_per_read_op': 'int',
        'usec_per_write_op': 'int',
        'write_bytes_per_sec': 'int',
        'writes_per_sec': 'int'
    }

    attribute_map = {
        'name': 'name',
        'bytes_per_op': 'bytes_per_op',
        'bytes_per_read': 'bytes_per_read',
        'bytes_per_write': 'bytes_per_write',
        'others_per_sec': 'others_per_sec',
        'read_bytes_per_sec': 'read_bytes_per_sec',
        'reads_per_sec': 'reads_per_sec',
        'time': 'time',
        'usec_per_other_op': 'usec_per_other_op',
        'usec_per_read_op': 'usec_per_read_op',
        'usec_per_write_op': 'usec_per_write_op',
        'write_bytes_per_sec': 'write_bytes_per_sec',
        'writes_per_sec': 'writes_per_sec'
    }

    def __init__(self, name=None, bytes_per_op=None, bytes_per_read=None, bytes_per_write=None, others_per_sec=None, read_bytes_per_sec=None, reads_per_sec=None, time=None, usec_per_other_op=None, usec_per_read_op=None, usec_per_write_op=None, write_bytes_per_sec=None, writes_per_sec=None):  # noqa: E501
        """ClientPerformance - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._bytes_per_op = None
        self._bytes_per_read = None
        self._bytes_per_write = None
        self._others_per_sec = None
        self._read_bytes_per_sec = None
        self._reads_per_sec = None
        self._time = None
        self._usec_per_other_op = None
        self._usec_per_read_op = None
        self._usec_per_write_op = None
        self._write_bytes_per_sec = None
        self._writes_per_sec = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if bytes_per_op is not None:
            self.bytes_per_op = bytes_per_op
        if bytes_per_read is not None:
            self.bytes_per_read = bytes_per_read
        if bytes_per_write is not None:
            self.bytes_per_write = bytes_per_write
        if others_per_sec is not None:
            self.others_per_sec = others_per_sec
        if read_bytes_per_sec is not None:
            self.read_bytes_per_sec = read_bytes_per_sec
        if reads_per_sec is not None:
            self.reads_per_sec = reads_per_sec
        if time is not None:
            self.time = time
        if usec_per_other_op is not None:
            self.usec_per_other_op = usec_per_other_op
        if usec_per_read_op is not None:
            self.usec_per_read_op = usec_per_read_op
        if usec_per_write_op is not None:
            self.usec_per_write_op = usec_per_write_op
        if write_bytes_per_sec is not None:
            self.write_bytes_per_sec = write_bytes_per_sec
        if writes_per_sec is not None:
            self.writes_per_sec = writes_per_sec

    @property
    def name(self):
        """Gets the name of this ClientPerformance.  # noqa: E501

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :return: The name of this ClientPerformance.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ClientPerformance.

        The name of the object (e.g., a file system or snapshot)  # noqa: E501

        :param name: The name of this ClientPerformance.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def bytes_per_op(self):
        """Gets the bytes_per_op of this ClientPerformance.  # noqa: E501

        Average operation size (read bytes+write bytes/read ops+write ops)  # noqa: E501

        :return: The bytes_per_op of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._bytes_per_op

    @bytes_per_op.setter
    def bytes_per_op(self, bytes_per_op):
        """Sets the bytes_per_op of this ClientPerformance.

        Average operation size (read bytes+write bytes/read ops+write ops)  # noqa: E501

        :param bytes_per_op: The bytes_per_op of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if bytes_per_op is not None and bytes_per_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `bytes_per_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._bytes_per_op = bytes_per_op

    @property
    def bytes_per_read(self):
        """Gets the bytes_per_read of this ClientPerformance.  # noqa: E501

        Average read size in bytes per read operation  # noqa: E501

        :return: The bytes_per_read of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._bytes_per_read

    @bytes_per_read.setter
    def bytes_per_read(self, bytes_per_read):
        """Sets the bytes_per_read of this ClientPerformance.

        Average read size in bytes per read operation  # noqa: E501

        :param bytes_per_read: The bytes_per_read of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if bytes_per_read is not None and bytes_per_read < 0:  # noqa: E501
            raise ValueError("Invalid value for `bytes_per_read`, must be a value greater than or equal to `0`")  # noqa: E501

        self._bytes_per_read = bytes_per_read

    @property
    def bytes_per_write(self):
        """Gets the bytes_per_write of this ClientPerformance.  # noqa: E501

        Average write size in bytes per write operation  # noqa: E501

        :return: The bytes_per_write of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._bytes_per_write

    @bytes_per_write.setter
    def bytes_per_write(self, bytes_per_write):
        """Sets the bytes_per_write of this ClientPerformance.

        Average write size in bytes per write operation  # noqa: E501

        :param bytes_per_write: The bytes_per_write of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if bytes_per_write is not None and bytes_per_write < 0:  # noqa: E501
            raise ValueError("Invalid value for `bytes_per_write`, must be a value greater than or equal to `0`")  # noqa: E501

        self._bytes_per_write = bytes_per_write

    @property
    def others_per_sec(self):
        """Gets the others_per_sec of this ClientPerformance.  # noqa: E501

        Other operations processed per second  # noqa: E501

        :return: The others_per_sec of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._others_per_sec

    @others_per_sec.setter
    def others_per_sec(self, others_per_sec):
        """Sets the others_per_sec of this ClientPerformance.

        Other operations processed per second  # noqa: E501

        :param others_per_sec: The others_per_sec of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if others_per_sec is not None and others_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `others_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._others_per_sec = others_per_sec

    @property
    def read_bytes_per_sec(self):
        """Gets the read_bytes_per_sec of this ClientPerformance.  # noqa: E501

        Bytes read per second  # noqa: E501

        :return: The read_bytes_per_sec of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._read_bytes_per_sec

    @read_bytes_per_sec.setter
    def read_bytes_per_sec(self, read_bytes_per_sec):
        """Sets the read_bytes_per_sec of this ClientPerformance.

        Bytes read per second  # noqa: E501

        :param read_bytes_per_sec: The read_bytes_per_sec of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if read_bytes_per_sec is not None and read_bytes_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `read_bytes_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._read_bytes_per_sec = read_bytes_per_sec

    @property
    def reads_per_sec(self):
        """Gets the reads_per_sec of this ClientPerformance.  # noqa: E501

        Read requests processed per second  # noqa: E501

        :return: The reads_per_sec of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._reads_per_sec

    @reads_per_sec.setter
    def reads_per_sec(self, reads_per_sec):
        """Sets the reads_per_sec of this ClientPerformance.

        Read requests processed per second  # noqa: E501

        :param reads_per_sec: The reads_per_sec of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if reads_per_sec is not None and reads_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `reads_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._reads_per_sec = reads_per_sec

    @property
    def time(self):
        """Gets the time of this ClientPerformance.  # noqa: E501

        Sample time in milliseconds since UNIX epoch  # noqa: E501

        :return: The time of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ClientPerformance.

        Sample time in milliseconds since UNIX epoch  # noqa: E501

        :param time: The time of this ClientPerformance.  # noqa: E501
        :type: int
        """

        self._time = time

    @property
    def usec_per_other_op(self):
        """Gets the usec_per_other_op of this ClientPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the client to process other operations  # noqa: E501

        :return: The usec_per_other_op of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_other_op

    @usec_per_other_op.setter
    def usec_per_other_op(self, usec_per_other_op):
        """Sets the usec_per_other_op of this ClientPerformance.

        Average time, measured in microseconds, it takes the client to process other operations  # noqa: E501

        :param usec_per_other_op: The usec_per_other_op of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_other_op is not None and usec_per_other_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_other_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_other_op = usec_per_other_op

    @property
    def usec_per_read_op(self):
        """Gets the usec_per_read_op of this ClientPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the client to process a read request  # noqa: E501

        :return: The usec_per_read_op of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_read_op

    @usec_per_read_op.setter
    def usec_per_read_op(self, usec_per_read_op):
        """Sets the usec_per_read_op of this ClientPerformance.

        Average time, measured in microseconds, it takes the client to process a read request  # noqa: E501

        :param usec_per_read_op: The usec_per_read_op of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_read_op is not None and usec_per_read_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_read_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_read_op = usec_per_read_op

    @property
    def usec_per_write_op(self):
        """Gets the usec_per_write_op of this ClientPerformance.  # noqa: E501

        Average time, measured in microseconds, it takes the client to process a write request  # noqa: E501

        :return: The usec_per_write_op of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._usec_per_write_op

    @usec_per_write_op.setter
    def usec_per_write_op(self, usec_per_write_op):
        """Sets the usec_per_write_op of this ClientPerformance.

        Average time, measured in microseconds, it takes the client to process a write request  # noqa: E501

        :param usec_per_write_op: The usec_per_write_op of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if usec_per_write_op is not None and usec_per_write_op < 0:  # noqa: E501
            raise ValueError("Invalid value for `usec_per_write_op`, must be a value greater than or equal to `0`")  # noqa: E501

        self._usec_per_write_op = usec_per_write_op

    @property
    def write_bytes_per_sec(self):
        """Gets the write_bytes_per_sec of this ClientPerformance.  # noqa: E501

        Bytes written per second  # noqa: E501

        :return: The write_bytes_per_sec of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._write_bytes_per_sec

    @write_bytes_per_sec.setter
    def write_bytes_per_sec(self, write_bytes_per_sec):
        """Sets the write_bytes_per_sec of this ClientPerformance.

        Bytes written per second  # noqa: E501

        :param write_bytes_per_sec: The write_bytes_per_sec of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if write_bytes_per_sec is not None and write_bytes_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `write_bytes_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._write_bytes_per_sec = write_bytes_per_sec

    @property
    def writes_per_sec(self):
        """Gets the writes_per_sec of this ClientPerformance.  # noqa: E501

        Write requests processed per second  # noqa: E501

        :return: The writes_per_sec of this ClientPerformance.  # noqa: E501
        :rtype: int
        """
        return self._writes_per_sec

    @writes_per_sec.setter
    def writes_per_sec(self, writes_per_sec):
        """Sets the writes_per_sec of this ClientPerformance.

        Write requests processed per second  # noqa: E501

        :param writes_per_sec: The writes_per_sec of this ClientPerformance.  # noqa: E501
        :type: int
        """
        if writes_per_sec is not None and writes_per_sec < 0:  # noqa: E501
            raise ValueError("Invalid value for `writes_per_sec`, must be a value greater than or equal to `0`")  # noqa: E501

        self._writes_per_sec = writes_per_sec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClientPerformance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClientPerformance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.6 Python SDK

    Pure Storage FlashBlade REST 1.6 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.6
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class FileSystemsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_file_systems(self, file_system, **kwargs):
        """
        Create a new file system
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_file_systems(file_system, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param FileSystem file_system: the attribute map used to create the file system. (required)
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_file_systems_with_http_info(file_system, **kwargs)
        else:
            (data) = self.create_file_systems_with_http_info(file_system, **kwargs)
            return data

    def create_file_systems_with_http_info(self, file_system, **kwargs):
        """
        Create a new file system
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_file_systems_with_http_info(file_system, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param FileSystem file_system: the attribute map used to create the file system. (required)
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['file_system']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_file_systems" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'file_system' is set
        if ('file_system' not in params) or (params['file_system'] is None):
            raise ValueError("Missing the required parameter `file_system` when calling `create_file_systems`")


        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'file_system' in params:
            body_params = params['file_system']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.6/file-systems', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FileSystemResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def create_filesystem_policies(self, **kwargs):
        """
        Create a connection between a file system and a policy
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_filesystem_policies(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :return: PolicyObjectsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_filesystem_policies_with_http_info(**kwargs)
        else:
            (data) = self.create_filesystem_policies_with_http_info(**kwargs)
            return data

    def create_filesystem_policies_with_http_info(self, **kwargs):
        """
        Create a connection between a file system and a policy
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_filesystem_policies_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :return: PolicyObjectsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['policy_names', 'member_names']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_filesystem_policies" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'policy_names' in params:
            query_params.append(('policy_names', params['policy_names']))
            collection_formats['policy_names'] = 'csv'
        if 'member_names' in params:
            query_params.append(('member_names', params['member_names']))
            collection_formats['member_names'] = 'csv'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.6/file-systems/policies', 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='PolicyObjectsResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_file_systems(self, name, **kwargs):
        """
        Delete a file system
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_file_systems(name, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: name of the file system to be deleted (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_file_systems_with_http_info(name, **kwargs)
        else:
            (data) = self.delete_file_systems_with_http_info(name, **kwargs)
            return data

    def delete_file_systems_with_http_info(self, name, **kwargs):
        """
        Delete a file system
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_file_systems_with_http_info(name, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: name of the file system to be deleted (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_file_systems" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params) or (params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `delete_file_systems`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in params:
            query_params.append(('name', params['name']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.6/file-systems', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_filesystem_policies(self, **kwargs):
        """
        Delete a connection between a file system and a policy.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_filesystem_policies(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_filesystem_policies_with_http_info(**kwargs)
        else:
            (data) = self.delete_filesystem_policies_with_http_info(**kwargs)
            return data

    def delete_filesystem_policies_with_http_info(self, **kwargs):
        """
        Delete a connection between a file system and a policy.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_filesystem_policies_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['policy_names', 'member_names']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_filesystem_policies" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'policy_names' in params:
            query_params.append(('policy_names', params['policy_names']))
            collection_formats['policy_names'] = 'csv'
        if 'member_names' in params:
            query_params.append(('member_names', params['member_names']))
            collection_formats['member_names'] = 'csv'

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.6/file-systems/policies', 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type=None,
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def list_file_systems(self, **kwargs):
        """
        List file systems
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_file_systems(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :param str filter: The filter to be used for query.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param int limit: limit, should be >= 0
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param bool total_only: Return only the total object.
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_file_systems_with_http_info(**kwargs)
        else:
            (data) = self.list_file_systems_with_http_info(**kwargs)
            return data

    def list_file_systems_with_http_info(self, **kwargs):
        """
        List file systems
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_file_systems_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :param str filter: The filter to be used for query.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param int limit: limit, should be >= 0
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param bool total_only: Return only the total object.
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['names', 'filter', 'sort', 'start', 'limit', 'token', 'total_only']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_file_systems" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'names' in params:
            query_params.append(('names', params['names']))
            collection_formats['names'] = 'csv'
        if 'filter' in params:
            query_params.append(('filter', params['filter']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'start' in params:
            query_params.append(('start', params['start']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'token' in params:
            query_params.append(('token', params['token']))
        if 'total_only' in params:
            query_params.append(('total_only', params['total_only']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.6/file-systems', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FileSystemResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def list_file_systems_performance(self, **kwargs):
        """
        List instant or historical file system performance.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_file_systems_performance(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int resolution: sample frequency in milliseconds
        :param str protocol: to sample performance of a certain protocol
        :param int end_time: Time to end sample in milliseconds since epoch.
        :param str filter: The filter to be used for query.
        :param int limit: limit, should be >= 0
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start_time: Time to start sample in milliseconds since epoch.
        :param int start: The offset of the first resource to return from a collection.
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param bool total_only: Return only the total object.
        :return: FileSystemPerformanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_file_systems_performance_with_http_info(**kwargs)
        else:
            (data) = self.list_file_systems_performance_with_http_info(**kwargs)
            return data

    def list_file_systems_performance_with_http_info(self, **kwargs):
        """
        List instant or historical file system performance.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_file_systems_performance_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int resolution: sample frequency in milliseconds
        :param str protocol: to sample performance of a certain protocol
        :param int end_time: Time to end sample in milliseconds since epoch.
        :param str filter: The filter to be used for query.
        :param int limit: limit, should be >= 0
        :param list[str] names: A comma-separated list of resource names. This cannot be provided together with the ids query parameters.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start_time: Time to start sample in milliseconds since epoch.
        :param int start: The offset of the first resource to return from a collection.
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :param bool total_only: Return only the total object.
        :return: FileSystemPerformanceResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['resolution', 'protocol', 'end_time', 'filter', 'limit', 'names', 'sort', 'start_time', 'start', 'token', 'total_only']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_file_systems_performance" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'resolution' in params:
            query_params.append(('resolution', params['resolution']))
        if 'protocol' in params:
            query_params.append(('protocol', params['protocol']))
        if 'end_time' in params:
            query_params.append(('end_time', params['end_time']))
        if 'filter' in params:
            query_params.append(('filter', params['filter']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'names' in params:
            query_params.append(('names', params['names']))
            collection_formats['names'] = 'csv'
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'start_time' in params:
            query_params.append(('start_time', params['start_time']))
        if 'start' in params:
            query_params.append(('start', params['start']))
        if 'token' in params:
            query_params.append(('token', params['token']))
        if 'total_only' in params:
            query_params.append(('total_only', params['total_only']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.6/file-systems/performance', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FileSystemPerformanceResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def list_filesystem_policies(self, **kwargs):
        """
        List policies attached to filesystems.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_filesystem_policies(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :param str filter: The filter to be used for query.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param int limit: limit, should be >= 0
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :return: PolicyObjectsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.list_filesystem_policies_with_http_info(**kwargs)
        else:
            (data) = self.list_filesystem_policies_with_http_info(**kwargs)
            return data

    def list_filesystem_policies_with_http_info(self, **kwargs):
        """
        List policies attached to filesystems.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.list_filesystem_policies_with_http_info(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param list[str] policy_names: A comma-separated list of policy names. This cannot be provided together with the policy ids query parameters.
        :param list[str] member_names: A comma-separated list of member names. This cannot be provided together with the member ids query parameters.
        :param str filter: The filter to be used for query.
        :param str sort: Sort the response by the specified fields (in descending order if '-' is appended to the field name).
        :param int start: The offset of the first resource to return from a collection.
        :param int limit: limit, should be >= 0
        :param str token: An opaque token used to iterate over a collection. The token to use on the next request is returned in the `continuation_token` field of the result.
        :return: PolicyObjectsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['policy_names', 'member_names', 'filter', 'sort', 'start', 'limit', 'token']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_filesystem_policies" % key
                )
            params[key] = val
        del params['kwargs']


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'policy_names' in params:
            query_params.append(('policy_names', params['policy_names']))
            collection_formats['policy_names'] = 'csv'
        if 'member_names' in params:
            query_params.append(('member_names', params['member_names']))
            collection_formats['member_names'] = 'csv'
        if 'filter' in params:
            query_params.append(('filter', params['filter']))
        if 'sort' in params:
            query_params.append(('sort', params['sort']))
        if 'start' in params:
            query_params.append(('start', params['start']))
        if 'limit' in params:
            query_params.append(('limit', params['limit']))
        if 'token' in params:
            query_params.append(('token', params['token']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.6/file-systems/policies', 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='PolicyObjectsResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_file_systems(self, name, attributes, **kwargs):
        """
        Update an existing file system
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_file_systems(name, attributes, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: the name of the file system to be updated (required)
        :param FileSystem attributes: the new attributes, only modifiable fields could be used. (required)
        :param bool ignore_usage: Allow update operations that lead to a hard_limit_enabled file system with usage over its provisioned size. The update can be either setting hard_limit_enabled when usage is higher than provisioned size, or resize provisioned size to a value under usage when hard_limit_enabled is True.
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_file_systems_with_http_info(name, attributes, **kwargs)
        else:
            (data) = self.update_file_systems_with_http_info(name, attributes, **kwargs)
            return data

    def update_file_systems_with_http_info(self, name, attributes, **kwargs):
        """
        Update an existing file system
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_file_systems_with_http_info(name, attributes, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str name: the name of the file system to be updated (required)
        :param FileSystem attributes: the new attributes, only modifiable fields could be used. (required)
        :param bool ignore_usage: Allow update operations that lead to a hard_limit_enabled file system with usage over its provisioned size. The update can be either setting hard_limit_enabled when usage is higher than provisioned size, or resize provisioned size to a value under usage when hard_limit_enabled is True.
        :return: FileSystemResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'attributes', 'ignore_usage']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_file_systems" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params) or (params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `update_file_systems`")
        # verify the required parameter 'attributes' is set
        if ('attributes' not in params) or (params['attributes'] is None):
            raise ValueError("Missing the required parameter `attributes` when calling `update_file_systems`")


        collection_formats = {}

        path_params = {}

        query_params = []
        if 'name' in params:
            query_params.append(('name', params['name']))
        if 'ignore_usage' in params:
            query_params.append(('ignore_usage', params['ignore_usage']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'attributes' in params:
            body_params = params['attributes']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['AuthTokenHeader']

        return self.api_client.call_api('/1.6/file-systems', 'PATCH',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='FileSystemResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Pure Storage FlashBlade REST 1.9 Python SDK

    Pure Storage FlashBlade REST 1.9 Python SDK, developed by [Pure Storage, Inc](http://www.purestorage.com/). Documentations can be found at [purity-fb.readthedocs.io](http://purity-fb.readthedocs.io/).

    OpenAPI spec version: 1.9
    Contact: info@purestorage.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class FileSystemSnapshotsTransfer(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

#BEGIN_CUSTOM
    # IR-51527: Prevent Pytest from attempting to collect this class based on name.
    __test__ = False
#END_CUSTOM

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'completed': 'int',
        'data_transferred': 'int',
        'direction': 'Direction',
        'progress': 'float',
        'remote': 'FixedReferenceWithId',
        'remote_snapshot': 'FixedReferenceWithId',
        'started': 'int',
        'status': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'completed': 'completed',
        'data_transferred': 'data_transferred',
        'direction': 'direction',
        'progress': 'progress',
        'remote': 'remote',
        'remote_snapshot': 'remote_snapshot',
        'started': 'started',
        'status': 'status'
    }

    def __init__(self, id=None, name=None, completed=None, data_transferred=None, direction=None, progress=None, remote=None, remote_snapshot=None, started=None, status=None):  # noqa: E501
        """FileSystemSnapshotsTransfer - a model defined in Swagger"""  # noqa: E501

        self._id = None
        self._name = None
        self._completed = None
        self._data_transferred = None
        self._direction = None
        self._progress = None
        self._remote = None
        self._remote_snapshot = None
        self._started = None
        self._status = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if completed is not None:
            self.completed = completed
        if data_transferred is not None:
            self.data_transferred = data_transferred
        if direction is not None:
            self.direction = direction
        if progress is not None:
            self.progress = progress
        if remote is not None:
            self.remote = remote
        if remote_snapshot is not None:
            self.remote_snapshot = remote_snapshot
        if started is not None:
            self.started = started
        if status is not None:
            self.status = status

    @property
    def id(self):
        """Gets the id of this FileSystemSnapshotsTransfer.  # noqa: E501

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :return: The id of this FileSystemSnapshotsTransfer.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FileSystemSnapshotsTransfer.

        A non-modifiable, globally unique ID chosen by the system.  # noqa: E501

        :param id: The id of this FileSystemSnapshotsTransfer.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this FileSystemSnapshotsTransfer.  # noqa: E501

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :return: The name of this FileSystemSnapshotsTransfer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this FileSystemSnapshotsTransfer.

        The name of the object (e.g., a file system or snapshot).  # noqa: E501

        :param name: The name of this FileSystemSnapshotsTransfer.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def completed(self):
        """Gets the completed of this FileSystemSnapshotsTransfer.  # noqa: E501

        A timestamp at which the replication of the snapshot completed.  # noqa: E501

        :return: The completed of this FileSystemSnapshotsTransfer.  # noqa: E501
        :rtype: int
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """Sets the completed of this FileSystemSnapshotsTransfer.

        A timestamp at which the replication of the snapshot completed.  # noqa: E501

        :param completed: The completed of this FileSystemSnapshotsTransfer.  # noqa: E501
        :type: int
        """

        self._completed = completed

    @property
    def data_transferred(self):
        """Gets the data_transferred of this FileSystemSnapshotsTransfer.  # noqa: E501

        The amount of data transferred to the target, in bytes.  # noqa: E501

        :return: The data_transferred of this FileSystemSnapshotsTransfer.  # noqa: E501
        :rtype: int
        """
        return self._data_transferred

    @data_transferred.setter
    def data_transferred(self, data_transferred):
        """Sets the data_transferred of this FileSystemSnapshotsTransfer.

        The amount of data transferred to the target, in bytes.  # noqa: E501

        :param data_transferred: The data_transferred of this FileSystemSnapshotsTransfer.  # noqa: E501
        :type: int
        """

        self._data_transferred = data_transferred

    @property
    def direction(self):
        """Gets the direction of this FileSystemSnapshotsTransfer.  # noqa: E501


        :return: The direction of this FileSystemSnapshotsTransfer.  # noqa: E501
        :rtype: Direction
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """Sets the direction of this FileSystemSnapshotsTransfer.


        :param direction: The direction of this FileSystemSnapshotsTransfer.  # noqa: E501
        :type: Direction
        """

        self._direction = direction

    @property
    def progress(self):
        """Gets the progress of this FileSystemSnapshotsTransfer.  # noqa: E501

        A percentage that indicates how much progress has been made on the transfer.  # noqa: E501

        :return: The progress of this FileSystemSnapshotsTransfer.  # noqa: E501
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this FileSystemSnapshotsTransfer.

        A percentage that indicates how much progress has been made on the transfer.  # noqa: E501

        :param progress: The progress of this FileSystemSnapshotsTransfer.  # noqa: E501
        :type: float
        """
        if progress is not None and progress > 1:  # noqa: E501
            raise ValueError("Invalid value for `progress`, must be a value less than or equal to `1`")  # noqa: E501
        if progress is not None and progress < 0:  # noqa: E501
            raise ValueError("Invalid value for `progress`, must be a value greater than or equal to `0`")  # noqa: E501

        self._progress = progress

    @property
    def remote(self):
        """Gets the remote of this FileSystemSnapshotsTransfer.  # noqa: E501

        The array where the remote file system snapshot is located.  # noqa: E501

        :return: The remote of this FileSystemSnapshotsTransfer.  # noqa: E501
        :rtype: FixedReferenceWithId
        """
        return self._remote

    @remote.setter
    def remote(self, remote):
        """Sets the remote of this FileSystemSnapshotsTransfer.

        The array where the remote file system snapshot is located.  # noqa: E501

        :param remote: The remote of this FileSystemSnapshotsTransfer.  # noqa: E501
        :type: FixedReferenceWithId
        """

        self._remote = remote

    @property
    def remote_snapshot(self):
        """Gets the remote_snapshot of this FileSystemSnapshotsTransfer.  # noqa: E501

        A reference to the associated remote file system snapshot.  # noqa: E501

        :return: The remote_snapshot of this FileSystemSnapshotsTransfer.  # noqa: E501
        :rtype: FixedReferenceWithId
        """
        return self._remote_snapshot

    @remote_snapshot.setter
    def remote_snapshot(self, remote_snapshot):
        """Sets the remote_snapshot of this FileSystemSnapshotsTransfer.

        A reference to the associated remote file system snapshot.  # noqa: E501

        :param remote_snapshot: The remote_snapshot of this FileSystemSnapshotsTransfer.  # noqa: E501
        :type: FixedReferenceWithId
        """

        self._remote_snapshot = remote_snapshot

    @property
    def started(self):
        """Gets the started of this FileSystemSnapshotsTransfer.  # noqa: E501

        A timestamp at which the replication of the snapshot started.  # noqa: E501

        :return: The started of this FileSystemSnapshotsTransfer.  # noqa: E501
        :rtype: int
        """
        return self._started

    @started.setter
    def started(self, started):
        """Sets the started of this FileSystemSnapshotsTransfer.

        A timestamp at which the replication of the snapshot started.  # noqa: E501

        :param started: The started of this FileSystemSnapshotsTransfer.  # noqa: E501
        :type: int
        """

        self._started = started

    @property
    def status(self):
        """Gets the status of this FileSystemSnapshotsTransfer.  # noqa: E501

        The status of current replication. Valid values are `completed`, `in-progress`, and `queued`.  # noqa: E501

        :return: The status of this FileSystemSnapshotsTransfer.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this FileSystemSnapshotsTransfer.

        The status of current replication. Valid values are `completed`, `in-progress`, and `queued`.  # noqa: E501

        :param status: The status of this FileSystemSnapshotsTransfer.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FileSystemSnapshotsTransfer, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileSystemSnapshotsTransfer):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
